import collections
import functools


@functools.lru_cache(None)
def max_val(n: int, a: int, b: int) -> int:
    """
    Given a state (a, b, c) and n characters remaining, what is the maximum value you can achieve?
    (a + x, b + (a + x)y, c + (b + (a + x)y)z)
    c + (b + (a + x)y)z
    c + bz + ayz + xyz
    """

    ans = 0
    for y in range(n + 1):
        for z in range(n + 1 - y):
            x = n - y - z
            ans = max(ans, b * z + a * y * z + x * y * z)

    return ans


def count_nac(s: str) -> int:
    state = [0, 0, 0]
    for c in s:
        if c == "N":
            state[0] += 1
        elif c == "A":
            state[1] += state[0]
        elif c == "C":
            state[2] += state[1]

    return state[2]


def main():
    n, k = map(int, input().split())
    s = list(input())
    assert len(s) == n

    @functools.lru_cache(None)
    def dfs(idx: int, state: tuple[int, int, int]):
        state = list(state)
        if idx == n:
            return s if state[-1] == k else None

        if state[2] > k:
            return None
        if state[2] < k and state[1] > k:
            return None

        max_can = max_val(n - idx, state[0], state[1]) + state[2]
        if max_can < k:
            return None

        if s[idx] == "N" or s[idx] == "?":
            old = s[idx]
            s[idx] = "N"
            state[0] += 1
            if res := dfs(idx + 1, tuple(state)):
                return res
            state[0] -= 1
            s[idx] = old

        if s[idx] == "A" or s[idx] == "?":
            old = s[idx]
            s[idx] = "A"
            state[1] += state[0]
            if res := dfs(idx + 1, tuple(state)):
                return res
            state[1] -= state[0]
            s[idx] = old

        if s[idx] == "C" or s[idx] == "?":
            old = s[idx]
            s[idx] = "C"
            state[2] += state[1]
            if res := dfs(idx + 1, tuple(state)):
                return res
            state[2] -= state[1]
            s[idx] = old

        if s[idx] not in "NAC":
            is_q = s[idx] == "?"
            if is_q:
                s[idx] = "Z"
            if res := dfs(idx + 1, tuple(state)):
                return res

            if is_q:
                s[idx] = "?"

    res = dfs(0, (0, 0, 0))
    if res is None:
        print(-1)
    else:
        ans = "".join(res)
        print(ans)
        # print(ans, count_nac(ans))
        assert count_nac(ans) == k


if __name__ == "__main__":
    main()
